OC.L10N.register(
    "settings",
    {
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Security & setup warnings" : "Avertissements de sécurité & configuration",
    "Sharing" : "Partage",
    "Server-side encryption" : "Chiffrement côté serveur",
    "External Storage" : "Stockage externe",
    "Cron" : "Cron",
    "Email server" : "Serveur e-mail",
    "Log" : "Log",
    "Tips & tricks" : "Trucs et astuces",
    "Updates" : "Mises à jour",
    "Couldn't remove app." : "Impossible de supprimer l'application.",
    "Language changed" : "Langue changée",
    "Invalid request" : "Requête non valide",
    "Authentication error" : "Erreur d'authentification",
    "Admins can't remove themself from the admin group" : "Les administrateurs ne peuvent pas se retirer eux-mêmes du groupe admin",
    "Unable to add user to group %s" : "Impossible d'ajouter l'utilisateur au groupe %s",
    "Unable to remove user from group %s" : "Impossible de supprimer l'utilisateur du groupe %s",
    "Couldn't update app." : "Impossible de mettre à jour l'application",
    "Wrong password" : "Mot de passe incorrect",
    "No user supplied" : "Aucun utilisateur fourni",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données de l'utilisateur seront perdues",
    "Wrong admin recovery password. Please check the password and try again." : "Mot de passe administrateur de récupération de données non valable. Veuillez vérifier le mot de passe et essayer à nouveau.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "L'infrastructure d'arrière-plan ne supporte pas la modification de mot de passe, mais la clef de chiffrement de l'utilisateur a été mise à jour avec succès.",
    "Unable to change password" : "Impossible de modifier le mot de passe",
    "Enabled" : "Activées",
    "Not enabled" : "Désactivées",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "le partage Federated Cloud ou l'installation et la mise à jour d'applications par l'app store",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL utilise %s %s, qui est une version obsolète. Veuillez mettre à jour votre système d'exploitation, ou des fonctionnalités telles que %s ne fonctionneront pas correctement.",
    "A problem occurred, please check your log files (Error: %s)" : "Une erreur est survenue, veuillez vérifier vos fichiers de log (Erreur: %s)",
    "Migration Completed" : "Migration terminée",
    "Group already exists." : "Ce groupe existe déjà.",
    "Unable to add group." : "Impossible d'ajouter le groupe.",
    "Unable to delete group." : "Impossible de supprimer le groupe.",
    "log-level out of allowed range" : "niveau de journalisation hors borne",
    "Saved" : "Sauvegardé",
    "test email settings" : "Test des paramètres e-mail",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres. (Erreur: %s)",
    "Email sent" : "E-mail envoyé",
    "You need to set your user email before being able to send test emails." : "Vous devez définir une adresse e-mail dans vos paramètres personnels avant de pouvoir envoyer des e-mails de test.",
    "Invalid mail address" : "Adresse e-mail non valide",
    "A user with that name already exists." : "Un utilisateur à ce nom existe déjà.",
    "Unable to create user." : "Impossible de créer l'utilisateur.",
    "Your %s account was created" : "Votre compte %s a été créé",
    "Unable to delete user." : "Impossible de supprimer l'utilisateur.",
    "Forbidden" : "interdit",
    "Invalid user" : "Utilisateur non valable",
    "Unable to change mail address" : "Impossible de modifier l'adresse e-mail",
    "Email saved" : "E-mail sauvegardé",
    "Your full name has been changed." : "Votre nom complet a été modifié.",
    "Unable to change full name" : "Impossible de changer le nom complet",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Êtes-vous vraiment sûr de vouloir ajouter \"{domain}\" comme domaine de confiance ?",
    "Add trusted domain" : "Ajouter un domaine de confiance",
    "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
    "Migration started …" : "Migration démarrée...",
    "Sending..." : "Envoi en cours...",
    "Official" : "Officielle",
    "Approved" : "Approuvée",
    "Experimental" : "Expérimentale",
    "All" : "Tous",
    "No apps found for your version" : "Pas d'application trouvée pour votre version",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Les applications officielles sont développées par et avec la communauté ownCloud. Elles permettent à ownCloud d'offrir ses fonctionnalités principales et sont prêtes pour une utilisation en environnement de production. ",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Les applications approuvées sont créées par des développeurs de confiance et ont passé les tests de sécurité. Elles sont activement maintenues et leur code source est ouvert. Leurs développeurs les considèrent stables pour une utilisation normale.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Cette application est nouvelle ou instable, et sa sécurité n'a pas été vérifiée. Installez-la à vos risques et périls!",
    "Update to %s" : "Mettre à niveau vers la version %s",
    "Please wait...." : "Veuillez patienter…",
    "Error while disabling app" : "Erreur lors de la désactivation de l'application",
    "Disable" : "Désactiver",
    "Enable" : "Activer",
    "Error while enabling app" : "Erreur lors de l'activation de l'application",
    "Updating...." : "Mise à jour...",
    "Error while updating app" : "Erreur lors de la mise à jour de l'application",
    "Updated" : "Mise à jour effectuée",
    "Uninstalling ...." : "Désinstallation...",
    "Error while uninstalling app" : "Erreur lors de la désinstallation de l'application",
    "Uninstall" : "Désinstaller",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'application a été activée mais doit être mise à jour. Vous allez être redirigé vers la page des mises à jour dans 5 secondes.",
    "App update" : "Mise à jour",
    "No apps found for \"{query}\"" : "Aucune application trouvée pour \"{query}\"",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Une erreur est survenue. Veuillez fournir un certificat PEM encodé au format ASCII.",
    "Valid until {date}" : "Valide jusqu'au {date}",
    "Delete" : "Supprimer",
    "An error occurred: {message}" : "Une erreur est survenue : {message}",
    "Select a profile picture" : "Selectionnez une photo de profil ",
    "Very weak password" : "Mot de passe de très faible sécurité",
    "Weak password" : "Mot de passe de faible sécurité",
    "So-so password" : "Mot de passe de sécurité tout juste acceptable",
    "Good password" : "Mot de passe de sécurité suffisante",
    "Strong password" : "Mot de passe de forte sécurité",
    "Groups" : "Groupes",
    "Unable to delete {objName}" : "Impossible de supprimer {objName}",
    "Error creating group: {message}" : "Erreur lors de la création du groupe : {message}",
    "A valid group name must be provided" : "Vous devez spécifier un nom de groupe valide",
    "deleted {groupName}" : "{groupName} supprimé",
    "undo" : "annuler",
    "no group" : "Aucun groupe",
    "never" : "jamais",
    "deleted {userName}" : "{userName} supprimé",
    "add group" : "ajouter un groupe",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "La modification du mot de passe entrainera la perte des données car la restauration de données n'est pas disponible pour cet utilisateur",
    "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
    "A valid password must be provided" : "Un mot de passe valide doit être saisi",
    "A valid email must be provided" : "Vous devez fournir une adresse e-mail valide",
    "__language_name__" : "Français",
    "Personal info" : "Informations personnelles",
    "Sync clients" : "Clients de synchronisation",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tout (erreurs fatales, erreurs, avertissements, informations, debogage)",
    "Info, warnings, errors and fatal issues" : "Informations, avertissements, erreurs et erreurs fatales",
    "Warnings, errors and fatal issues" : "Avertissements, erreurs et erreurs fatales",
    "Errors and fatal issues" : "Erreurs et erreurs fatales",
    "Fatal issues only" : "Erreurs fatales uniquement",
    "None" : "Aucun",
    "Login" : "Login",
    "Plain" : "En clair",
    "NT LAN Manager" : "Gestionnaire du réseau NT",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php ne semble pas être configuré de manière à récupérer les valeurs des variables d’environnement. Le test de la commande getenv(\"PATH\") retourne seulement une réponse vide. ",
    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Veuillez consulter <a target=\"_blank\" href=\"%s\">la documentation d'installation ↗</a> pour savoir comment configurer php sur votre serveur, en particulier en cas d'utilisation de php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuration est en mode lecture seule. Ceci empêche la modification de certaines configurations via l'interface web. De plus, le fichier doit être passé manuellement en lecture-écriture avant chaque mise à jour.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP est apparemment configuré pour supprimer les blocs de documentation internes. Cela rendra plusieurs applications de base inaccessibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Votre serveur fonctionne actuellement sur une plateforme Microsoft Windows. Nous vous recommandons fortement d'utiliser une plateforme Linux pour une expérience utilisateur optimale.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats de détection mime-type.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers est désactivé. Cela peut causer des conflits en cas d'accès concurrent. Configurez 'filelocking.enabled' dans config.php pour éviter ces problèmes. Consultez la <a target=\"_blank\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
    "System locale can not be set to a one which supports UTF-8." : "Les paramètres régionaux n'ont pu être configurés avec prise en charge d'UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Cela signifie qu'il pourrait y avoir des problèmes avec certains caractères dans les noms de fichier.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nous vous recommandons d'installer sur votre système les paquets nécessaires à la prise en charge de l'un des paramètres régionaux suivants : %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si votre installation n'a pas été effectuée à la racine du domaine et qu'elle utilise le cron du système, il peut y avoir des problèmes avec la génération d'URL. Pour les éviter, veuillez configurer l'option \"overwrite.cli.url\" de votre fichier config.php avec le chemin de la racine de votre installation (suggéré : \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Consultez les <a target=\"_blank\" href=\"%s\">guides d'installation ↗</a>,  et cherchez des erreurs ou avertissements dans  <a href=\"#log-section\">les logs</a>.",
    "All checks passed." : "Tous les tests ont réussi.",
    "Open documentation" : "Voir la documentation",
    "Allow apps to use the Share API" : "Autoriser les applications à utiliser l'API de partage",
    "Allow users to share via link" : "Autoriser les utilisateurs à partager par lien",
    "Enforce password protection" : "Imposer la protection par mot de passe",
    "Allow public uploads" : "Autoriser les téléversements publics",
    "Allow users to send mail notification for shared files" : "Autoriser les utilisateurs à envoyer des notifications de partage par e-mail",
    "Set default expiration date" : "Spécifier une date d'expiration par défaut",
    "Expire after " : "Expiration après ",
    "days" : "jours",
    "Enforce expiration date" : "Imposer la date d'expiration",
    "Allow resharing" : "Autoriser le repartage",
    "Restrict users to only share with users in their groups" : "N'autoriser les partages qu'entre membres de mêmes groupes",
    "Allow users to send mail notification for shared files to other users" : "Autoriser les utilisateurs à envoyer des notifications de partage par e-mail",
    "Exclude groups from sharing" : "Empêcher certains groupes de partager",
    "These groups will still be able to receive shares, but not to initiate them." : "Ces groupes ne pourront plus initier de partage, mais ils pourront toujours rejoindre les partages faits par d'autres. ",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Activer l'autocomplétion des noms d'utilisateurs dans la fenêtre de partage. Si cette option est désactivée,  les noms complets doivent être indiqués.",
    "Last cron job execution: %s." : "Dernière tâche cron exécutée : %s.",
    "Last cron job execution: %s. Something seems wrong." : "Dernière tâche cron exécutée : %s. Quelque chose s'est mal passé.",
    "Cron was not executed yet!" : "Le cron n'a pas encore été exécuté !",
    "Execute one task with each page loaded" : "Exécute une tâche à chaque chargement de page",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "Utilisez un service webcron pour exécuter cron.php toutes les 15 minutes par HTTP",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Utilisez le service cron du système pour appeler le fichier cron.php toutes les 15 minutes.",
    "Enable server-side encryption" : "Activer le chiffrement côté serveur",
    "Please read carefully before activating server-side encryption: " : "Veuillez lire ceci avec attention avant d'activer le chiffrement :",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Une fois le chiffrement activé, les fichiers téléversés sur le serveur à partir de ce moment seront stockés sous forme chiffrée. Il n'est possible de désactiver le chiffrement que si le module utilisé le permet spécifiquement, et que toutes les conditions préalables sont réunies pour ce faire (par exemple la création d'une clef de récupération).",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Le chiffrement seul ne peut garantir la sécurité du système. Veuillez consulter la documentation ownCloud pour comprendre comment fonctionne l'application de chiffrement, et les cas d'utilisation pris en charge.",
    "Be aware that encryption always increases the file size." : "Veuillez noter que le chiffrement augmente toujours la taille des fichiers.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Il est opportun de sauvegarder régulièrement vos données. Si ces données sont chiffrées, n'oubliez pas de sauvegarder aussi les clés de chiffrement.",
    "This is the final warning: Do you really want to enable encryption?" : "Dernier avertissement : Voulez-vous vraiment activer le chiffrement ?",
    "Enable encryption" : "Activer le chiffrement",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Aucun module de chiffrement n'est chargé. Merci d'activer un module de chiffrement dans le menu des applications.",
    "Select default encryption module:" : "Sélectionnez le module de chiffrement par défaut :",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle. Veuillez activer l'application \"Default Encryption Module\" et exécuter 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle.",
    "Start migration" : "Démarrer la migration",
    "This is used for sending out notifications." : "Ceci est utilisé pour l'envoi des notifications.",
    "Send mode" : "Mode d'envoi",
    "Encryption" : "Chiffrement",
    "From address" : "Adresse source",
    "mail" : "e-mail",
    "Authentication method" : "Méthode d'authentification",
    "Authentication required" : "Authentification requise",
    "Server address" : "Adresse du serveur",
    "Port" : "Port",
    "Credentials" : "Informations d'identification",
    "SMTP Username" : "Nom d'utilisateur SMTP",
    "SMTP Password" : "Mot de passe SMTP",
    "Store credentials" : "Enregistrer les identifiants",
    "Test email settings" : "Tester les paramètres e-mail",
    "Send email" : "Envoyer un e-mail",
    "Download logfile" : "Télécharger le fichier de journalisation",
    "More" : "Plus",
    "Less" : "Moins",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "La taille du fichier journal excède 100 Mo. Le télécharger peut prendre un certain temps!",
    "What to log" : "Ce qu'il faut journaliser",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite est actuellement utilisé comme gestionnaire de base de données. Pour des installations plus volumineuses, nous vous conseillons d'utiliser un autre gestionnaire de base de données.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'utilisation de SQLite est particulièrement déconseillée si vous utilisez le client de bureau pour synchroniser vos données.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type' ou consultez la <a target=\"_blank\" href=\"%s\">documentation ↗</a>.",
    "How to do backups" : "Comment faire des sauvegardes",
    "Advanced monitoring" : "Surveillance avancée",
    "Performance tuning" : "Ajustement des performances",
    "Improving the config.php" : "Amélioration du config.php ",
    "Theming" : "Personnalisation de l'apparence",
    "Hardening and security guidance" : "Guide pour le renforcement et la sécurité",
    "Version" : "Version",
    "Developer documentation" : "Documentation pour développeurs",
    "Experimental applications ahead" : "Attention! Applications expérimentales",
    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Les applications expérimentales n'ont pas fait l'objet de tests de sécurité, sont encore en développement et peuvent être instables. Les installer peut causer des pertes de données ou des failles de sécurité. ",
    "by %s" : "par %s",
    "%s-licensed" : "Sous licence %s",
    "Documentation:" : "Documentation :",
    "User documentation" : "Documentation utilisateur",
    "Admin documentation" : "Documentation administrateur",
    "Show description …" : "Afficher la description...",
    "Hide description …" : "Masquer la description",
    "This app has an update available." : "Cette application a une mise à jour disponible.",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Cette app ne spécifie pas de version d'ownCloud minimale requise. Cela provoquera une erreur dans ownCloud 11+",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Cette app ne spécifie pas de version d'ownCloud maximale requise. Cela provoquera une erreur dans ownCloud 11+",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Cette application ne peut être installée à cause de ces dépendances non satisfaites :",
    "Enable only for specific groups" : "Activer uniquement pour certains groupes",
    "Uninstall App" : "Désinstaller l'application",
    "Enable experimental apps" : "Activer les applications expérimentales",
    "SSL Root Certificates" : "Certificats Racines SSL",
    "Common Name" : "Nom d'usage",
    "Valid until" : "Valide jusqu'à",
    "Issued By" : "Délivré par",
    "Valid until %s" : "Valide jusqu'à %s",
    "Import root certificate" : "Importer un certificat racine",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Bonjour,<br><br>Un compte %s a été créé pour vous.<br><br>Votre nom d'utilisateur est : %s<br>Visitez votre compte : <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "À bientôt !",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Bonjour,<br><br>Un compte %s a été créé pour vous.<br><br>Votre nom d'utilisateur est : %s<br>Visitez votre compte : %s<br><br>\n",
    "Administrator documentation" : "Documentation administrateur",
    "Online documentation" : "Documentation en ligne",
    "Forum" : "Forum",
    "Issue tracker" : "Suivi de problèmes",
    "Commercial support" : "Support commercial",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Vous utilisez <strong>%s</strong> des <strong>%s<strong> disponibles",
    "Profile picture" : "Photo de profil",
    "Upload new" : "Nouvelle depuis votre ordinateur",
    "Select from Files" : "Sélectionner depuis les Fichiers",
    "Remove image" : "Supprimer l'image",
    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 Mo",
    "Picture provided by original account" : "Photo fournie par le compte original",
    "Cancel" : "Annuler",
    "Choose as profile picture" : "Définir comme image de profil",
    "Full name" : "Nom complet",
    "No display name set" : "Aucun nom d'affichage configuré",
    "Email" : "Adresse e-mail",
    "Your email address" : "Votre adresse e-mail",
    "For password recovery and notifications" : "Pour la récupération de mot de passe et les notifications",
    "No email address set" : "Aucune adresse e-mail configurée",
    "You are member of the following groups:" : "Vous êtes membre des groupes suivants :",
    "Password" : "Mot de passe",
    "Unable to change your password" : "Impossible de changer votre mot de passe",
    "Current password" : "Mot de passe actuel",
    "New password" : "Nouveau mot de passe",
    "Change password" : "Changer de mot de passe",
    "Language" : "Langue",
    "Help translate" : "Aidez à traduire",
    "Get the apps to sync your files" : "Obtenez les applications de synchronisation de vos fichiers",
    "Desktop client" : "Client de bureau",
    "Android app" : "Application Android",
    "iOS app" : "Application iOS",
    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Si vous souhaitez apporter votre support au projet\n        <a href=\"https://owncloud.org/contribute\"\n            target=\"_blank\" rel=\"noreferrer\">rejoignez le développement</a>\n        ou\n        <a href=\"https://owncloud.org/promote\"\n            target=\"_blank\" rel=\"noreferrer\">faites passer le mot</a> !",
    "Show First Run Wizard again" : "Revoir la fenêtre d'accueil affichée lors de votre première connexion",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Développé par la {communityopen}communauté ownCloud{linkclose}, le {githubopen}code source{linkclose} est sous licence {licenseopen}<abbr lang=\"en\" title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Show storage location" : "Afficher l'emplacement du stockage",
    "Show last log in" : "Montrer la dernière connexion",
    "Show user backend" : "Montrer la source de l'identifiant",
    "Send email to new user" : "Envoyer un e-mail aux utilisateurs créés",
    "Show email address" : "Afficher l'adresse e-mail",
    "Username" : "Nom d'utilisateur",
    "E-Mail" : "E-Mail",
    "Create" : "Créer",
    "Admin Recovery Password" : "Mot de passe Administrateur de récupération",
    "Enter the recovery password in order to recover the users files during password change" : "Entrez le mot de passe de récupération pour récupérer les fichiers utilisateurs pendant le changement de mot de passe",
    "Add Group" : "Ajouter un groupe",
    "Group" : "Groupe",
    "Everyone" : "Tout le monde",
    "Admins" : "Administrateurs",
    "Default Quota" : "Quota par défaut",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Veuillez entrer le quota de stockage (ex. \"512 MB\" ou \"12 GB\")",
    "Unlimited" : "Illimité",
    "Other" : "Autre",
    "Full Name" : "Nom complet",
    "Group Admin for" : "Administrateur de groupe pour",
    "Quota" : "Quota",
    "Storage Location" : "Emplacement du Stockage",
    "User Backend" : "Source",
    "Last Login" : "Dernière Connexion",
    "change full name" : "Modifier le nom complet",
    "set new password" : "Changer le mot de passe",
    "change email address" : "changer l'adresse e-mail",
    "Default" : "Défaut"
},
"nplurals=2; plural=(n > 1);");
